@@ -7,7 +7,7 @@ use crate::render::pipeline::TERMINAL_RENDERER_PIPELINE;
 
 use super::{
     renderer_tile_data::TerminalRendererTileData, renderer_vertex_data::TerminalRendererVertexData,
-    TerminalRendererFont, TerminalTileScaling,
+    TerminalPivot, TerminalRendererFont, TerminalTileScaling, TilePivot,
 };
 
 #[derive(Bundle)]
@@ -22,6 +22,8 @@ pub struct TerminalRendererBundle {
     pub visible: Visible,
     pub render_pipelines: RenderPipelines,
     pub main_pass: MainPass,
+    pub terminal_pivot: TerminalPivot,
+    pub tile_pivot: TilePivot,
 }
 
 impl Default for TerminalRendererBundle {
@@ -40,6 +42,8 @@ impl Default for TerminalRendererBundle {
             mesh: Default::default(),
             draw: Default::default(),
             main_pass: Default::default(),
+            terminal_pivot: Default::default(),
+            tile_pivot: Default::default(),
         }
     }
 }
